==> qtjambi-sensors-5.15.14-sources.jar: io/qt/sensors/QLidSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qlidsensor.html">QLidSensor</a></p>
 */
public class QLidSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLidSensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QLidSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlidsensor.html#QLidSensor">QLidSensor::QLidSensor(QObject*)</a></p>
     */
    public QLidSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLidSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsensor.html#reading-prop">QSensor::reading()const</a></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QLidReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QLidReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QLidSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QLidSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QLidSensor instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sensors-6.2.1-sources.jar: io/qt/sensors/QLidSensor.java <==
package io.qt.sensors;


/**
 * <p>Java wrapper for Qt class QLidSensor</p>
 */
public class QLidSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLidSensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QLidSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QLidSensor() {
        this((io.qt.core.QObject)null);
    }
    
    public QLidSensor(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLidSensor instance, io.qt.core.QObject parent);
    
    @io.qt.QtUninvokable
    public final io.qt.sensors.QLidReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.sensors.QLidReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLidSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLidSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLidSensor instance, QDeclarativeConstructor constructor);
    
}
